@@ -90,9 +90,9 @@ const manifestExtra = {
     permissions: permissionsExtra,
     options_ui: {},
     web_accessible_resources: [
-        // wtf?? it says that content scritps don't need to be listed... but doesn't work otherwise..
+        // wtf?? it says that content scripts don't need to be listed... but doesn't work otherwise..
         // https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/manifest.json/web_accessible_resources#Description
-        "vendors_anchorme.js",
+        "anchorme.js",
         // TODO however, seems that web_accessible_resources works without sidebar.js and sidebar.css?? odd
     ],
 };
@@ -169,6 +169,7 @@ const options = {
     background_injector     : path.join(__dirname, './src/background_injector'),
   },
   output: {
+    publicPath: '', // https://stackoverflow.com/a/64715069
     path: buildPath,
     filename: '[name].js',
     // chunkFilename: '[name].bundle.js',
@@ -209,6 +210,8 @@ const options = {
                       {code: /RSVP.Promise/g, newCode: 'Promise'},
                       {code: 'RSVP.all', newCode: 'Promise.all'},
                       {code: 'window.basket = {', newCode: 'var basket = window.basket= {'},
+                      // ugh. sometimes it patches it twice somehow??? wtf???
+                      {code: 'var basket = var basket = window.basket= {', newCode: 'var basket = window.basket= {'},
                   ],
               }
           },
@@ -230,20 +233,22 @@ const options = {
     ]
   },
   plugins: [
-   new CleanWebpackPlugin(), // ok, respects symlinks
-   new CopyWebpackPlugin([
-      { from: 'images/*' },
-      { from: 'src/*.html'     , flatten: true},
-      { from: 'src/*.css'      , flatten: true},
-      { from: 'src/toastify.js', flatten: true}, // TODO my version is tweaked, right?
-      { from: 'src/showvisited.js', flatten: true},
-      // { from: 'node_modules/webextension-polyfill/dist/browser-polyfill.min.js'},
-    ]),
+    new CleanWebpackPlugin(), // ok, respects symlinks
+    new CopyWebpackPlugin({
+      patterns: [
+        { from: 'images/*'          },
+        { from: 'src/**/*.html', to: '[name][ext]'},
+        { from: 'src/**/*.css' , to: '[name][ext]'},
+        { from: 'src/toastify.js'   }, // TODO my version is tweaked, right?
+        { from: 'src/showvisited.js'},
+        // { from: 'node_modules/webextension-polyfill/dist/browser-polyfill.min.js'},
+       ]
+    }),
     new WebpackExtensionManifestPlugin({
-        config: {
-            base: baseManifest,
-            extend: manifestExtra,
-        }
+      config: {
+        base: baseManifest,
+        extend: manifestExtra,
+      }
     }),
   ]
 };
