@@ -352,6 +352,9 @@ def main() -> None:
     ccp.add_argument('--config', type=Path, default=default_config_path(), help='Config path')
 
     icp = scp.add_parser('create', help='Create user config')
+    icp.add_argument(
+        "--config", type=Path, default=default_config_path(), help="Config path"
+    )
     icp.set_defaults(func=config_create)
 
     dp = subp.add_parser('doctor', help='Troubleshooting assistant')
@@ -374,7 +377,7 @@ def main() -> None:
 
     logger.info("CLI args: %s", args)
 
-    # TODO maybe, it's better for server to compute intermediate represetnation?
+    # TODO maybe, it's better for server to compute intermediate representations?
     # the only downside is storage. dunno.
     # worst case -- could use database?
 
