@@ -45,7 +45,7 @@ class Loc(NamedTuple):
 
         # todo: handler has to be overridable by config. This is needed for docker, but also for a "as a service" install, where the sources would be available on some remote webserver
         # maybe it should be treated as a format string, so that {line} may be a part of the result or not.
-        # for local usage, editor:///file:line works, but if the txt file is only avaiable through http, it breaks.
+        # for local usage, editor:///file:line works, but if the txt file is only available through http, it breaks.
         #if get_config().MIME_HANDLER:
         #   handler = get_config().MIME_HANDLER
         #if True:
@@ -222,7 +222,7 @@ def _sanitize(url: str) -> str:
 
 def iter_urls(s: str, *, syntax: Syntax='') -> Iterable[Url]:
     extractor = _get_extractor(syntax=syntax)
-    # note: it also has get_indices, might be usefull
+    # note: it also has get_indices, might be useful
     for u in extractor.gen_urls(s):
         yield _sanitize(u)
 
@@ -325,7 +325,7 @@ def echain(ex: Exception, cause: Exception) -> Exception:
     # right.. even if we attach cause it doesn't help much because when we return/yield exception, we lose the stacktrace
     # so only 'ex' gets logged, cause is completely lost
     # hopefully this is safe? at least on runtimeerrors
-    # might also do something smarter and collapes if both are strings or something..
+    # might also do something smarter and collapse if both are strings or something..
     e.args += cause.args
     return e
 
@@ -431,7 +431,7 @@ def fdfind_args(root: Path, follow: bool, ignore: List[str]=[]) -> List[str]:
 
     ignore_args = []
     if ignore:
-        # Add a statment that excludes the folder
+        # Add a statement that excludes the folder
         ignore_args = [['--exclude', f'{n}'] for n in ignore]
         # Flatten the list of lists
         ignore_args_l = list(itertools.chain(*ignore_args))
@@ -487,8 +487,18 @@ def traverse(root: Path, *, follow: bool=True, ignore: List[str]=[]) -> Iterable
 @lru_cache(1)
 def get_system_zone() -> str:
     try:
-        import tzlocal # type: ignore
-        return tzlocal.get_localzone().zone
+        import tzlocal
+        # note: tzlocal mypy stubs aren't aware of api change yet (see https://github.com/python/typeshed/issues/6038)
+        try:
+            # 4.0 way
+            return tzlocal.get_localzone_name() # type: ignore[attr-defined]
+        except AttributeError as e:
+            # 2.0 way
+            zone = tzlocal.get_localzone().zone  # type: ignore[attr-defined]
+            # see https://github.com/python/typeshed/blame/968fd6d01d23470e0c8368e7ee7c43f54aaedc0e/stubs/pytz/pytz/tzinfo.pyi#L6
+            # it says all concrete instances should not be None
+            assert zone is not None
+            return zone
     except Exception as e:
         logger.exception(e)
         logger.error("Couldn't determine system timezone. Falling back to UTC. Please report this as a bug!")
@@ -505,6 +515,12 @@ def get_system_tz() -> pytz.BaseTzInfo:
         logger.error(f"Unknown time zone %s. Falling back to UTC. Please report this as a bug!", zone)
         return pytz.utc
 
+# used in misc/install_server.py
+def root() -> Path:
+    r = Path(__file__).absolute().parent.parent.parent
+    assert (r / 'src').exists()
+    return r
+
 
 def file_mtime(path: PathIsh) -> datetime:
     tz = get_system_tz()
@@ -516,7 +532,10 @@ def now_tz() -> datetime:
 
 
 def user_config_file() -> Path:
-    return Path(appdirs().user_config_dir) / 'config.py'
+    if "PROMNESIA_CONFIG" in os.environ:
+        return Path(os.environ["PROMNESIA_CONFIG"])
+    else:
+        return Path(appdirs().user_config_dir) / 'config.py'
 
 
 def default_config_path() -> Path:
