@@ -5,6 +5,7 @@
 
 import csv
 from concurrent.futures import ProcessPoolExecutor as Pool
+from contextlib import nullcontext
 from datetime import datetime
 import itertools
 import json
@@ -19,10 +20,11 @@ import pytz
 
 from ..common import Visit, Url, PathIsh, get_logger, Loc, get_tmpdir, extract_urls, Extraction, Result, Results, mime, traverse, file_mtime, echain, logger
 from ..config import use_cores
-from ..py37 import nullcontext
 
 
 from .filetypes import EUrl
+from .obsidian import obsidian_replacer
+from .logseq import logseq_replacer
 
 
 def _collect(thing, path: List[str], result: List[EUrl]) -> None:
@@ -44,7 +46,7 @@ def _collect(thing, path: List[str], result: List[EUrl]) -> None:
         pass
 
 
-# TOOD mm. okay, I suppose could use kython consuming thingy?..
+# TODO mm. okay, I suppose could use kython consuming thingy?..
 def collect_from(thing) -> List[EUrl]:
     uuu: List[EUrl] = []
     path: List[str] = []
@@ -88,7 +90,7 @@ def fallback(ex):
         if not do_fallback:
             try:
                 it = ex(path)
-                # ugh. keeping yeild in the try section is not ideal, but need this because of lazy yield semantics
+                # ugh. keeping yield in the try section is not ideal, but need this because of lazy yield semantics
                 yield from it
             except ModuleNotFoundError as me:
                 logger = get_logger()
@@ -157,7 +159,7 @@ for t in CODE:
 # TODO ok, mime doesn't really tell between org/markdown/etc anyway
 
 
-Replacer = Optional[Callable[[str], str]]
+Replacer = Optional[Callable[[str, str], str]]
 
 def index(
         *paths: Union[PathIsh],
@@ -176,6 +178,18 @@ def index(
         # TODO for displaying maybe better not to expand/absolute, but need it for correct mime handling
         apath = Path(p).expanduser().resolve().absolute()
         root = apath if apath.is_dir() else None
+
+        if root is not None and (root / ".obsidian").exists():
+            if replacer:
+                logger.debug('detected %s as Obsidian vault, but not changing replacer', root)
+            else:
+                logger.debug('detected %s as Obsidian vault', root)
+                replacer = obsidian_replacer
+
+        if root is not None and (root / "logseq/config.edn").exists():
+            logger.debug('detected %s as Logseq graph', root)
+            replacer = logseq_replacer
+
         opts = Options(
             ignored=ignored,
             follow=follow,
@@ -207,6 +221,7 @@ def _index(path: Path, opts: Options) -> Results:
 
     cores = use_cores()
     if cores is None: # do not use cores
+        # todo use ExitStack instead?
         pool = nullcontext()
         mapper = map # dummy pool
     else:
@@ -268,11 +283,18 @@ def _index_file(pp: Path, opts: Options) -> Results:
 
     if suf == '.xz': # TODO zstd?
         import lzma
-        uname = pp.name[:-len('.xz')]
-        uncomp = Path(get_tmpdir().name) / uname
+        uname = pp.name[:-len('.xz')]  # chop off suffix, so the downstream indexer can handle it
+
+        assert pp.is_absolute(), pp
+        # make sure to keep hierarchy, otherwise might end up with some name conflicts if filenames clash
+        uncomp = Path(get_tmpdir().name) / Path(*pp.parts[1:-1]) / uname
+        uncomp.parent.mkdir(parents=True, exist_ok=True)
+        # todo would dump_file = wdir / Path(*cleaned_db.parts[1:])  # cut off '/' and use relative path
         with lzma.open(pp, 'rb') as cf:
             with uncomp.open('wb') as fb:
                 fb.write(cf.read())
+        # TODO maybe keep the original name?
+        # currently it would end up with something like /tmp/tmpxpgx1jy2promnesia/reddit-20190401231025.json
         yield from _index(path=uncomp, opts=opts)
         return
 
@@ -280,7 +302,7 @@ def _index_file(pp: Path, opts: Options) -> Results:
 
     ip, pm = by_path(pp)
     if ip is None:
-        # TOOD use warning (with mime/ext as key?)
+        # TODO use warning (with mime/ext as key?)
         # TODO only log once? # hmm..
         msg = f'No extractor for suffix {suf}, mime {pm}'
         warnings.warn(msg)
@@ -323,14 +345,14 @@ def _index_file(pp: Path, opts: Options) -> Results:
             loc = loc._replace(title=loc.title.replace(str(root) + os.sep, ''))
             v = v._replace(locator=loc)
 
-        if replacer is not None:
+        if replacer is not None and root is not None:
             upd: Dict[str, Any] = {}
             href = v.locator.href
             if href is not None:
-                upd['locator'] = v.locator._replace(href=replacer(href), title=replacer(v.locator.title))
+                upd['locator'] = v.locator._replace(href=replacer(href, str(root)), title=replacer(v.locator.title, str(root)))
             ctx = v.context
             if ctx is not None:
                 # TODO in context, http is unnecessary
-                upd['context'] = replacer(ctx)
+                upd['context'] = replacer(ctx, str(root))
             v = v._replace(**upd)
         yield v
