@@ -5,8 +5,6 @@ from subprocess import check_call, run, Popen
 from textwrap import dedent
 from typing import Set, Dict, Optional, Union, Sequence, Tuple, Mapping, List
 
-from promnesia.py37 import fromisoformat
-
 import pytest
 
 from common import tdir, under_ci, DATA, GIT_ROOT, promnesia_bin
@@ -126,18 +124,17 @@ def index_some_demo_visits(
 
     # todo would be nice if it was possible without importing anything at all
     def make_visits():
-        from datetime import timedelta
+        from datetime import timedelta, datetime
         from promnesia.sources import demo
-        from promnesia.py37 import fromisoformat
 
         # todo hmm, a bit messy, would be nice to do it in a more straighforward manner..
         yield from demo.index(
             count={count},
-            base_dt=fromisoformat('{base_dt.isoformat()}'),
+            base_dt=datetime.fromisoformat('{base_dt.isoformat()}'),
             delta=timedelta(seconds={delta.total_seconds()}),
         )
 
-    from promnesia import Source
+    from promnesia.common import Source
     SOURCES = [
         Source(make_visits, name='demo'),
     ]
@@ -230,7 +227,7 @@ def test_index_many(tdir: Path) -> None:
     cfg = tdir / 'test_config.py'
     cfg.write_text(f"""
 from datetime import datetime, timedelta
-from promnesia import Source, Visit, Loc
+from promnesia.common import Source, Visit, Loc
 # TODO def need to allow taking in index function without having to wrap in source?
 def index():
     for i in range(100000):
@@ -255,7 +252,7 @@ def test_indexing_error(tdir: Path) -> None:
 def bad_index():
     import bad_import
     yield from [] # dummy
-from promnesia import Source
+from promnesia.common import Source
 from promnesia.sources import demo
 
 SOURCES = [
@@ -283,7 +280,7 @@ def test_indexing_update(tmp_path: Path) -> None:
     counter = Counter(v.src for v in visits)
     assert counter['hyp'] > 50, counter  # precondition
 
-    dt = fromisoformat('2018-06-01T10:00:00.000000+01:00')
+    dt = datetime.fromisoformat('2018-06-01T10:00:00.000000+01:00')
     index_some_demo_visits(tmp_path, count=1000, base_dt=dt, delta=timedelta(hours=1), update=True)
     visits = query_db_visits(tmp_path)
     counter = Counter(v.src for v in visits)
@@ -297,7 +294,7 @@ def test_concurrent_indexing(tmp_path: Path, execution_number) -> None:
     cfg_fast = tmp_path / 'config_fast.py'
     cfg = dedent(f'''
     OUTPUT_DIR = r'{tmp_path}'
-    from promnesia import Source
+    from promnesia.common import Source
     from promnesia.sources import demo
     SOURCES = [Source(demo.index, count=COUNT)]
     ''')
